@@ -8,15 +8,10 @@ __docformat__ = "restructuredtext en"
 _ = unicode
 
 from cubicweb.web import uicfg
-from cubicweb.web.views import schema
 from cubicweb.web.views.urlrewrite import (
     SimpleReqRewriter, SchemaBasedRewriter, rgx, build_rset)
 
 
-schema.SKIP_TYPES.add('see_also')
-schema.ALWAYS_SKIP_TYPES.add('see_also')
-
-
 def fixed_orderby_rql(sortsdef, asc=True):
     orderby = []
     for rtype, varname in sortsdef:
